@@ -18,6 +18,18 @@ class CognitoAPIHandler(APIHandler):
         model = get_model(userinfo)
         self.write(json.dumps(model))
 
+    async def post(self):
+        user = self.current_user
+        if user is None:
+            raise web.HTTPError(403)
+        userinfo = self.authenticator.refresh_user_token(user.name)
+        get_model = self.userinfo_model
+        # ensure we have permission to identify ourselves
+        # all tokens can do this on this endpoint
+        model = get_model(userinfo)
+        self.write(json.dumps(model))
+        self.set_status(201)
+
     def userinfo_model(self, userinfo):
         if isinstance(userinfo, UserInfo):
             user = userinfo
