@@ -510,3 +510,25 @@ class CognitoAuthenticator(Authenticator):
             "IdToken": user.id_token,
             "RefreshToken": user.refresh_token,
         }
+
+    def refresh_user_token(self, username):
+        user = self.get_user(username)
+        # update db
+        try:
+            CognitoCli = boto3.client("cognito-idp", region_name=self.CognitoRegion)
+            response = CognitoCli.initiate_auth(
+                AuthFlow="REFRESH_TOKEN_AUTH",
+                ClientId=self.CognitoClientId,
+                AuthParameters={
+                    'REFRESH_TOKEN': user.refresh_token
+                }
+            )
+            self.successful_login(
+                username,
+                response["AuthenticationResult"]["AccessToken"],
+                response["AuthenticationResult"]["IdToken"],
+                response["AuthenticationResult"]["RefreshToken"]
+                )
+            return user
+        except print(0):
+            pass
